==> mosh-0.0.7.tar.gz: mosh-0.0.7/BinaryOutputPort.h <==
/*
 * BinaryOutputPort.h - 
 *
 *   Copyright (c) 2008  Higepon(Taro Minowa)  <higepon@users.sourceforge.jp>
 *
 *   Redistribution and use in source and binary forms, with or without
 *   modification, are permitted provided that the following conditions
 *   are met:
 *
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 *
 *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *   A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *   OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 *   TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 *   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 *   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 *   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 *   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *  $Id: BinaryOutputPort.h 261 2008-07-25 06:16:44Z higepon $
 */

#ifndef __SCHEME_BINARY_OUTPUT_PORT__
#define __SCHEME_BINARY_OUTPUT_PORT__

#include "scheme.h"

namespace scheme {

class ByteVector;

class BinaryOutputPort EXTEND_GC
{
public:
    virtual ~BinaryOutputPort() {};
    virtual int putU8(uint8_t v) = 0;
    virtual int putU8(uint8_t* v, int size) = 0;
    virtual int putByteVector(ByteVector bv, int start = 0) = 0;
    virtual int putByteVector(ByteVector bv, int start, int count) = 0;
    virtual int open() = 0;
    virtual int close() = 0;
};

}; // namespace scheme

#endif // __SCHEME_BINARY_OUTPUT_PORT__

==> mosh-0.1.0.tar.gz: mosh-0.1.0/BinaryOutputPort.h <==
/*
 * BinaryOutputPort.h - 
 *
 *   Copyright (c) 2008  Higepon(Taro Minowa)  <higepon@users.sourceforge.jp>
 *
 *   Redistribution and use in source and binary forms, with or without
 *   modification, are permitted provided that the following conditions
 *   are met:
 *
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 *
 *   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *   "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *   A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *   OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *   SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 *   TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 *   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 *   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 *   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 *   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *  $Id: BinaryOutputPort.h 1568 2009-04-14 05:08:14Z herumi@nifty.com $
 */

#ifndef SCHEME_BINARY_OUTPUT_PORT_
#define SCHEME_BINARY_OUTPUT_PORT_

#include "OSCompat.h"
#include "BinaryPort.h"
#include "OutputPort.h"

namespace scheme {

class ByteVector;

class BinaryOutputPort : virtual public BinaryPort,
                         virtual public OutputPort
{
public:
    virtual ~BinaryOutputPort() {}
    virtual int putU8(uint8_t v) = 0;
    virtual int64_t putU8(uint8_t* v, int64_t size) = 0;
    virtual int64_t putByteVector(ByteVector* bv, int64_t start = 0) = 0;
    virtual int64_t putByteVector(ByteVector* bv, int64_t start, int64_t count) = 0;
    virtual void flush() = 0;
};

} // namespace scheme

#endif // SCHEME_BINARY_OUTPUT_PORT_
